<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SelectAll</name>
    <message>
        <location filename="../SelectAllInit.js" line="+2"/>
        <source>Select &amp;All</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Zaznacz &amp;wszystko
Odznacz &amp;wszystko</translatorcomment>
        <translation>Zaznacz &amp;wszystko</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Select all visible entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zaznacza wszystkie widoczne obiekty</translation>
    </message>
</context>
</TS>
